@@ -13,8 +13,8 @@ REFLECTION_MODELS = {
     'fatti': reflection.fatti,
     'shuey2': reflection.shuey2,
     'shuey3': reflection.shuey3,
-#    'bortfeld2': reflection.bortfeld2, 
-#    'bortfeld3': reflection.bortfeld3,
+    'bortfeld2': reflection.bortfeld2, 
+    'bortfeld3': reflection.bortfeld3,
              }
 
 WAVELETS = {
